@@ -20,30 +20,40 @@ KGameRendererClientPrivate::KGameRendererClientPrivate(KGameRenderer *renderer,
 }
 
 KGameRendererClient::KGameRendererClient(KGameRenderer *renderer, const QString &spriteKey)
-    : d(new KGameRendererClientPrivate(renderer, spriteKey, this))
+    : d_ptr(new KGameRendererClientPrivate(renderer, spriteKey, this))
 {
-    renderer->d->m_clients.insert(this, QString());
+    Q_D(KGameRendererClient);
+
+    renderer->d_ptr->m_clients.insert(this, QString());
     // The following may not be triggered directly because it may call receivePixmap() which is a pure virtual method at this point.
-    QTimer::singleShot(0, d.get(), &KGameRendererClientPrivate::fetchPixmap);
+    QTimer::singleShot(0, d, &KGameRendererClientPrivate::fetchPixmap);
 }
 
 KGameRendererClient::~KGameRendererClient()
 {
-    d->m_renderer->d->m_clients.remove(this);
+    Q_D(KGameRendererClient);
+
+    d->m_renderer->d_ptr->m_clients.remove(this);
 }
 
 KGameRenderer *KGameRendererClient::renderer() const
 {
+    Q_D(const KGameRendererClient);
+
     return d->m_renderer;
 }
 
 QString KGameRendererClient::spriteKey() const
 {
+    Q_D(const KGameRendererClient);
+
     return d->m_spec.spriteKey;
 }
 
 void KGameRendererClient::setSpriteKey(const QString &spriteKey)
 {
+    Q_D(KGameRendererClient);
+
     if (d->m_spec.spriteKey != spriteKey) {
         d->m_spec.spriteKey = spriteKey;
         d->fetchPixmap();
@@ -52,16 +62,22 @@ void KGameRendererClient::setSpriteKey(const QString &spriteKey)
 
 int KGameRendererClient::frameCount() const
 {
+    Q_D(const KGameRendererClient);
+
     return d->m_renderer->frameCount(d->m_spec.spriteKey);
 }
 
 int KGameRendererClient::frame() const
 {
+    Q_D(const KGameRendererClient);
+
     return d->m_spec.frame;
 }
 
 void KGameRendererClient::setFrame(int frame)
 {
+    Q_D(KGameRendererClient);
+
     if (d->m_spec.frame != frame) {
         // do some normalization ourselves
         const int frameCount = this->frameCount();
@@ -80,11 +96,15 @@ void KGameRendererClient::setFrame(int frame)
 
 QSize KGameRendererClient::renderSize() const
 {
+    Q_D(const KGameRendererClient);
+
     return d->m_spec.size;
 }
 
-void KGameRendererClient::setRenderSize(const QSize &renderSize)
+void KGameRendererClient::setRenderSize(QSize renderSize)
 {
+    Q_D(KGameRendererClient);
+
     if (d->m_spec.size != renderSize) {
         d->m_spec.size = renderSize;
         d->fetchPixmap();
@@ -93,11 +113,15 @@ void KGameRendererClient::setRenderSize(const QSize &renderSize)
 
 QHash<QColor, QColor> KGameRendererClient::customColors() const
 {
+    Q_D(const KGameRendererClient);
+
     return d->m_spec.customColors;
 }
 
 void KGameRendererClient::setCustomColors(const QHash<QColor, QColor> &customColors)
 {
+    Q_D(KGameRendererClient);
+
     if (d->m_spec.customColors != customColors) {
         d->m_spec.customColors = customColors;
         d->fetchPixmap();
@@ -106,5 +130,5 @@ void KGameRendererClient::setCustomColors(const QHash<QColor, QColor> &customCol
 
 void KGameRendererClientPrivate::fetchPixmap()
 {
-    m_renderer->d->requestPixmap(m_spec, m_parent);
+    m_renderer->d_ptr->requestPixmap(m_spec, m_parent);
 }
